@@ -106,7 +106,7 @@ class ExcelMorning():
         
         df = self.get_data(formula, variables_name, wait_time)# introduce formula and get the data
         
-        self.hold_info.at[serie_code,:] = [len(df.index), len(df.columns), df.isnull().sum().sum(), 
+        self.hold_info.loc[serie_code,:] = [len(df.index), len(df.columns), df.isnull().sum().sum(), 
                                 df.size, datetime.datetime.now(), "'"+formula.replace('""','"')]
         # Clean & prepare attributes data
         df['serie_code'] = serie_code
